drop table if exists realiza;
drop table if exists aterriza;
drop table if exists transporta;
drop table if exists cubre;
drop table if exists empleado;
drop table if exists muelle;
drop table if exists auxiliar_vuelo;
drop table if exists piloto;
drop table if exists mantenimiento;
drop table if exists avion;
drop table if exists sucursal_aerolinea;
drop table if exists escala;
drop table if exists cargo;
drop table if exists aeropuerto;
drop table if exists ruta;
drop table if exists aerolinea;
drop table if exists pasajero;

create table pasajero (
Cod_pasajero numeric(8) constraint pk_pasajero primary key,
Nombre_Pasaj varchar(40) constraint nn_pasajero not null,
Nacionalidad varchar(20),
Fecha_nac date,
Telefono varchar(20)
);

create table aerolinea (
Cod_aerolinea numeric(8) constraint pk_aerolinea primary key,
Nombre_aerolinea varchar(40) constraint nn_aerolinea not null
);

create table ruta (
Cod_ruta numeric(8) constraint pk_ruta primary key,
Ciudad_origen varchar(30),
Ciudad_destino varchar(30),
Distancia numeric(4)
);

create table aeropuerto (
Cod_aerop numeric(8) constraint pk_aeropuerto  primary key,
Nombre varchar(40) constraint nn_aeropuerto  not null,
Ciudad varchar(40)
);

create table cargo (
Cod_carg numeric(8) constraint pk_cargo  primary key,
Nom_carg varchar(40) constraint nn_cargo  not null
);

create table escala (
Cod_escala numeric(8) constraint pk_escala primary key,
Ciudad varchar(50) constraint nn_escala not null
);

create table sucursal_aerolinea (
Cod_suc_aerolinea numeric(8) constraint pk_suc_aer primary key,
Ciudad varchar(30) constraint nn_suc_aer not null,
Telefono varchar(20),
Cod_aerolinea numeric(8),
constraint fk_suc_aer foreign key(cod_aerolinea) references aerolinea(cod_aerolinea) on delete cascade
);

create table avion (
Num_avion numeric(8) constraint pk_avion  primary key,
Tipo_avion varchar(20) constraint nn_avion  not null,
Capacidad numeric(3),
Autonomia_vuelo numeric(8),
Año_fabric numeric(4),
Cod_aerolinea numeric(8),
constraint fk_avion foreign key(cod_aerolinea) references aerolinea(Cod_aerolinea) on delete cascade
);

create table mantenimiento (
Codigo_mant numeric(8) constraint pk_mantenimiento primary key,
Descripcion_mant varchar(100) constraint nn_mantenimiento not null,
Duracion_mant numeric(4),
Cod_avion numeric(8),
constraint fk_mantenimiento foreign key(cod_avion) references avion(num_avion) on delete cascade
);

create table piloto (
Cod_pil numeric(8) constraint pk_piloto primary key,
Nom_pil varchar(50) constraint nn_piloto not null,
Horas_vuelo numeric(4),
Fecha_nac date,
Salario numeric(8),
Cod_avion numeric(8),
constraint fk_piloto foreign key(cod_avion) references avion(num_avion) on delete cascade
);

create table auxiliar_vuelo(
Cod_auxiliar numeric(8) constraint pk_auxiliar_vuelo primary key,
Nom_auxiliar varchar(50) constraint nn_auxiliar_vuelo not null,
Gen_auxiliar varchar(2),
Fecha_nac date,
Salario numeric(8),
Cod_avion numeric(8),
constraint fk_auxiliar_vuelo foreign key(cod_avion) references avion(num_avion) on delete cascade
);

create table muelle (
Cod_muelle numeric(8) constraint pk_muelle primary key,
Tipo_muelle varchar(50) constraint nn_muelle not null,
Capacidad_aviones_muelle numeric(4),
Cod_aeropuerto numeric(8),
constraint fk_muelle foreign key(cod_aeropuerto) references aeropuerto(Cod_aerop) on delete cascade
);

create table empleado (
Cod_empleado numeric(8) constraint pk_empleado  primary key,
Nom_empleado varchar(50) constraint nn_empleado not null,
Fecha_nac_empleado date,
Salario numeric(8),
Cod_aeropuerto numeric(8),
constraint fk1_empleado foreign key(cod_aeropuerto) references aeropuerto(Cod_aerop) on delete cascade,
Cod_cargo numeric(8),
constraint fk2_empleado foreign key(cod_cargo) references cargo(Cod_carg) on delete cascade
);

create table cubre (
Codigo numeric(8) constraint pk_cubre primary key,
Fecha date,
Cod_avion numeric(8),
constraint fk1_cubre foreign key(cod_avion) references avion(num_avion) on delete cascade,
Cod_ruta numeric(8),
constraint fk2_cubre foreign key(Cod_ruta) references ruta(Cod_ruta) on delete cascade
);

create table transporta (
Fecha date,
Cod_avion numeric(8),
constraint fk1_transporta foreign key(cod_avion) references avion(num_avion) on delete cascade,
Cod_pasajero numeric(8),
constraint fk2_transporta foreign key(cod_pasajero) references pasajero(Cod_pasajero) on delete cascade,
constraint pk_transporta primary key(fecha,cod_avion,cod_pasajero)
);

create table aterriza (
Fecha date,
Cod_avion numeric(8),
constraint fk1_aterriza foreign key(cod_avion) references avion(num_avion) on delete cascade,
Cod_aeropuerto numeric(8),
constraint fk_aterriza foreign key(cod_aeropuerto) references aeropuerto(Cod_aerop) on delete cascade,
constraint pk_aterriza primary key(fecha,cod_avion,cod_aeropuerto)
);

create table realiza (
Cod_avion numeric(8),
constraint fk1_realiza foreign key(cod_avion) references avion(num_avion) on delete cascade,
Cod_escala numeric(8),
constraint fk_realiza foreign key(cod_escala) references escala(Cod_escala) on delete cascade,
Fecha date,
constraint pk_realiza primary key(fecha,cod_avion,cod_escala)
);

insert into pasajero values (1,'luis','colombiano','05/03/1988','6555555');
insert into pasajero values (2,'luisa','peruano','15/06/1975','6333333');
insert into pasajero values (3,'Rosalba','italiano','04/03/1970','6444444');
insert into pasajero values (4,'emilson','rumano','23/11/1982','6222222');
insert into pasajero values (5,'estela','peruano','01/12/1965','6111111');
insert into pasajero values (6,'raul','brasilero','16/07/1970','6666666');
insert into pasajero values (7,'nestor','colombiano','29/03/1960','6777777');
insert into pasajero values (8,'ruben','colombiano','28/05/1973','6888888');
insert into pasajero values (9,'dario','venezolano','22/03/1955','6999999');
insert into pasajero values (10,'alberto','chileno','26/07/1966','6444455');
insert into pasajero values (11,'adriana','colombiano','28/06/1977','6444466');
insert into pasajero values (12,'erika','canadiense','24/08/1957','6444477');
insert into pasajero values (13,'luis','colombiano','14/10/1990','6444433');
insert into pasajero values (14,'ramiro','chileno','22/04/1989','6444422');
insert into pasajero values (15,'reynaldo','ecuatoriano','01/03/1992','6444411');
insert into pasajero values (16,'raul','brasilero','17/07/1980','6663333');
insert into pasajero values (17,'hector','frances','24/03/1990','6774444');
insert into pasajero values (18,'ruben','frances','25/05/1979','6885555');
insert into pasajero values (19,'libardo','canadiense','26/03/1985','6666699');
insert into pasajero values (20,'alberto','italiano','28/07/1969','6477775');
insert into pasajero values (21,'rosita','colombiano','25/06/1997','6787866');
insert into pasajero values (22,'edith','frances','24/08/1956','6498777');
insert into pasajero values (23,'luis','canadiense','14/10/1998','6446543');
insert into pasajero values (24,'ruben','chileno','22/01/1988','6443672');
insert into pasajero values (25,'rey','italiano','01/05/1991','6444900');
insert into pasajero values (26,'raul','brasilero','17/06/1980','6663656');
insert into pasajero values (27,'hector','canadiense','24/05/1990','6774545');
insert into pasajero values (28,'ruben','frances','25/07/1979','6885343');
insert into pasajero values (29,'roque','venezolano','26/07/1985','6666212');
insert into pasajero values (30,'alberto','italiano','28/08/1969','6477321');
insert into pasajero values (31,'rosita','colombiano','25/08/1997','6787432');
insert into pasajero values (32,'edith','frances','24/09/1956','6498543');
insert into pasajero values (33,'luisa','colombiano','15/10/1998','6446654');
insert into pasajero values (34,'rosa','chileno','22/05/1988','6443765');
insert into pasajero values (35,'rey','italiano','05/05/1991','6444876');
insert into pasajero values (36,'raul','brasilero','12/07/1980','6663987');
insert into pasajero values (37,'hector','argentino','24/03/1990','6774098');
insert into pasajero values (38,'rudolf','aleman','22/05/1979','6885890');
insert into pasajero values (39,'mick','canadiense','22/03/1985','6666789');
insert into pasajero values (40,'albert','italiano','21/07/1969','6477678');
insert into pasajero values (41,'rosita','colombiano','21/06/1997','6787567');
insert into pasajero values (42,'edith','frances','24/08/1956','6498456');
insert into pasajero values (43,'luisa','colombiano','14/10/1998','6446345');
insert into pasajero values (44,'reuben','frances','22/01/1988','6443234');
insert into pasajero values (45,'ricki','italiano','01/05/1991','6444123');
insert into pasajero values (46,'raoul','brasilero','12/09/1981','6663987');
insert into pasajero values (47,'hermes','aleman','20/03/1992','6774098');
insert into pasajero values (48,'ruben','argentino','29/04/1973','6885890');
insert into pasajero values (49,'litrt','aleman','28/05/1984','6666789');
insert into pasajero values (50,'albert','italiano','27/06/1965','6477678');
insert into pasajero values (51,'adolf','aleman','16/07/1980','6612366');
insert into pasajero values (52,'nestor','colombiano','29/03/1980','6777369');
insert into pasajero values (53,'gret','aleman','18/05/1978','6888156');
insert into pasajero values (54,'dario','italiano','22/03/1958','6996329');
insert into pasajero values (55,'alberto','chileno','16/07/1986','6444015');
insert into pasajero values (56,'adriana','colombiano','21/06/1979','6442366');
insert into pasajero values (57,'edilma','canadiense','24/08/1997','6443277');
insert into pasajero values (58,'luisa','peruano','14/11/1991','6443573');
insert into pasajero values (59,'richi','chileno','21/04/1981','6445622');
insert into pasajero values (60,'rey','peruano','01/03/1992','6446511');
insert into pasajero values (61,'raul','brasilero','11/07/1970','6666896');
insert into pasajero values (62,'nestor','holandes','21/06/1960','6777897');
insert into pasajero values (63,'edith','colombiano','28/05/1973','6884788');
insert into pasajero values (64,'dairo','uruguayo','22/06/1956','6999589');
insert into pasajero values (65,'albert','canadiense','26/06/1966','6444125');

insert into aerolinea values (1,'aerorepublica');
insert into aerolinea values (2,'avianca');
insert into aerolinea values (3,'sam');
insert into aerolinea values (4,'satena');
insert into aerolinea values (5,'aires');
insert into aerolinea values (6,'lac');
insert into aerolinea values (7,'canjet');
insert into aerolinea values (8,'tango');
insert into aerolinea values (9,'westjet');
insert into aerolinea values (10,'air france');
insert into aerolinea values (11,'alitalia');
insert into aerolinea values (12,'belavie');
insert into aerolinea values (13,'qantas');
insert into aerolinea values (14,'vanair');
insert into aerolinea values (15,'virgin blue');

insert into ruta values (1,'bucaramanga','bogota',320);
insert into ruta values (2,'bucaramanga','cali',530);
insert into ruta values (3,'cali','bogota',270);
insert into ruta values (4,'bogota','pereira',200);
insert into ruta values (5,'barranquilla','cartagena',110);
insert into ruta values (6,'cartagena','cucuta',320);
insert into ruta values (7,'pereira','manizales',80);
insert into ruta values (8,'cali','popayan',120);
insert into ruta values (9,'bogota','bucaramanga',320);
insert into ruta values (10,'cucuta','bogota',540);
insert into ruta values (11,'bucaramanga','barrancabermeja',110);
insert into ruta values (12,'popayan','cali',230);
insert into ruta values (13,'cali','pereira',270);
insert into ruta values (14,'bogota','armenia',360);
insert into ruta values (15,'barranquilla','santa marta',160);
insert into ruta values (16,'santa marta','cartagena',280);
insert into ruta values (17,'pereira','armenia',80);
insert into ruta values (18,'cali','pasto',280);
insert into ruta values (19,'medellin','bucaramanga',320);
insert into ruta values (20,'cucuta','cartagena',540);


insert into aeropuerto values (1,'la nubia', 'manizales');
insert into aeropuerto values (2,'palonegro', 'bucaramanga');
insert into aeropuerto values (3,'el dorado', 'bogota');
insert into aeropuerto values (4,'alfonso bonilla aragon', 'cali');
insert into aeropuerto values (5,'camilo daza', 'cucuta');
insert into aeropuerto values (6,'vanguardia', 'villavicencio');
insert into aeropuerto values (7,'rafael nuñez', 'cartagena');
insert into aeropuerto values (8,'gustavo rojas pinilla', 'san andres isla');
insert into aeropuerto values (9,'el eden', 'armenia');
insert into aeropuerto values (10,'guillermo leon valencia', 'popayan');
insert into aeropuerto values (11,'perales', 'ibague');
insert into aeropuerto values (12,'matecaña', 'pereira');
insert into aeropuerto values (13,'alfredo vasquez cobo', 'leticia');
insert into aeropuerto values (14,'matecaña', 'pereira');
insert into aeropuerto values (15,'simon bolivar', 'santa marta');
insert into aeropuerto values (16,'santiago perez quiroz', 'arauca');
insert into aeropuerto values (17,'benito salas', 'neiva');
insert into aeropuerto values (18,'carano', 'quibdo');
insert into aeropuerto values (19,'alfonso lopez pumarejo', 'valledupar');
insert into aeropuerto values (20,'almirante padilla', 'riohacha');

insert into cargo values (1,'maletero');
insert into cargo values (2,'aseador');
insert into cargo values (3,'vigilante');
insert into cargo values (4,'guia');
insert into cargo values (5,'informacion');
insert into cargo values (6,'secretaria');

insert into escala values (1, 'bogota');
insert into escala values (2, 'cali');
insert into escala values (3, 'bucaramanga');
insert into escala values (4, 'pereira');
insert into escala values (5, 'ibague');
insert into escala values (6, 'armenia');
insert into escala values (7, 'cucuta');
insert into escala values (8, 'pasto');
insert into escala values (9, 'manizales');
insert into escala values (10, 'cartagena');
insert into escala values (11, 'barranquilla');
insert into escala values (12, 'santa marta');
insert into escala values (13, 'pasto');
insert into escala values (14, 'pitalito');
insert into escala values (15, 'san gil');
insert into escala values (16, 'riohacha');
insert into escala values (17, 'pamplona');
insert into escala values (18, 'popayan');
insert into escala values (19, 'la tebaida');
insert into escala values (20, 'cartago');

insert into sucursal_aerolinea values (1, 'bucaramanga', '6323458', 4);
insert into sucursal_aerolinea values (2, 'cali','6321567', 6);
insert into sucursal_aerolinea values (3, 'pereira', '6321756', 5);
insert into sucursal_aerolinea values (4, 'bogota','6321548', 4);
insert into sucursal_aerolinea values (5, 'manizales', '6321788', 1);
insert into sucursal_aerolinea values (6, 'cartagena', '6321777', 1);
insert into sucursal_aerolinea values (7, 'medellin', '6321666', 2);
insert into sucursal_aerolinea values (8, 'bucaramanga', '6321555', 2);
insert into sucursal_aerolinea values (9, 'cali','6321222', 2);
insert into sucursal_aerolinea values (10, 'armenia', '6321212', 3);
insert into sucursal_aerolinea values (11, 'bucaramanga', '6321321', 3);
insert into sucursal_aerolinea values (12, 'cali','632234', 5);
insert into sucursal_aerolinea values (13, 'pereira', '6321548', 4);
insert into sucursal_aerolinea values (14, 'bogota','6333338', 5);
insert into sucursal_aerolinea values (15, 'cucuta', '6324448', 6);
insert into sucursal_aerolinea values (16, 'cartagena', '6355548', 2);
insert into sucursal_aerolinea values (17, 'barranquilla', '6366548', 2);
insert into sucursal_aerolinea values (18, 'bogota','6321778', 3);
insert into sucursal_aerolinea values (19, 'cucuta', '6321768', 1);
insert into sucursal_aerolinea values (20, 'cartagena', '6321758', 1);
insert into sucursal_aerolinea values (21, 'bucaramanga', '6378548', 2);
insert into sucursal_aerolinea values (22, 'cali','6321898', 2);
insert into sucursal_aerolinea values (23, 'pereira', '6321590', 5);
insert into sucursal_aerolinea values (24, 'barranquilla','6321598', 4);
insert into sucursal_aerolinea values (25, 'santa marta', '6326576', 6);
insert into sucursal_aerolinea values (26, 'cartagena', '6321553', 6);
insert into sucursal_aerolinea values (27, 'medellin', '6321680', 4);


insert into avion values (1,'airbus a320',150,12000,2007,5);
insert into avion values (2,'boeing 747',280,18000,2002,4);
insert into avion values (3,'fokker 100',80,10000,2001,11);
insert into avion values (4,'boeing 767',300,25000,2004,9);
insert into avion values (5,'aTR 42',50,30000,2004,6);
insert into avion values (6,'boeing 757',350,26000,2006,12);
insert into avion values (7,'airbus a320',150,40000,2008,4);
insert into avion values (8,'cesna',20,35000,2005,5);
insert into avion values (9,'airbus a310',240,30000,2006,4);
insert into avion values (10,'airbus a310',240,50000,2005,13);
insert into avion values (11,'boeing 747',280,45000,2005,6);
insert into avion values (12,'saab 340',30,34000,2006,6);
insert into avion values (13,'cesna',20,35000,2005,4);
insert into avion values (14,'boeing 767',200,25000,2005,7);
insert into avion values (15,'aTR 42',150,30000,2004,11);
insert into avion values (16,'boeing 757',320,26000,2005,12);
insert into avion values (17,'airbus a320',120,40000,2005,14);
insert into avion values (18,'cesna',30,35000,2005,15);
insert into avion values (19,'airbus a310',140,30000,2007,4);
insert into avion values (20,'airbus a310',210,50000,2007,13);
insert into avion values (21,'boeing 747',220,45000,2007,6);
insert into avion values (22,'saab 340',30,34000,2007,6);
insert into avion values (23,'cesna',25,35000,2005,4);
insert into avion values (24,'boeing 767',300,25000,2009,13);
insert into avion values (25,'aTR 42',50,30000,2009,6);
insert into avion values (26,'boeing 757',320,25000,2010,12);
insert into avion values (27,'airbus a320',120,30000,2009,14);
insert into avion values (28,'cesna',30,35000,2010,15);
insert into avion values (29,'airbus a310',140,32000,2008,4);
insert into avion values (30,'airbus a310',210,30000,2007,13);

insert into mantenimiento values (1,'revision general del motor',20,9);
insert into mantenimiento values (2,'cambio de motor',30,3);
insert into mantenimiento values (3,'ajuste del tren delantero',15,10);
insert into mantenimiento values (4,'cambio de llantas',4,6);
insert into mantenimiento values (5,'ajuste de silleteria',20,7);
insert into mantenimiento values (6,'pintura interna',20,5);
insert into mantenimiento values (7,'cambio de vidrios delanteros',10,8);
insert into mantenimiento values (8,'limpieza de baños',5,4);
insert into mantenimiento values (9,'ajuste del aleron trasero',5,4);
insert into mantenimiento values (10,'sellado de las ventanas',50,8);
insert into mantenimiento values (11,'revision de turbina',50,3);
insert into mantenimiento values (12,'revision general del motor',50,7);
insert into mantenimiento values (13,'ajuste del tren delantero',15,6);
insert into mantenimiento values (14,'ajuste de silleteria',20,8);
insert into mantenimiento values (15,'pintura interna',20,5);
insert into mantenimiento values (16,'pintura interna',20,9);
insert into mantenimiento values (17,'cambio de motor',30,13);
insert into mantenimiento values (18,'cambio de motor',30,9);

insert into piloto values (1,'javier',1200,'03/03/1970',5300,13);
insert into piloto values (2,'luis',2000,'07/06/1966',4500,14);
insert into piloto values (3,'Jose',2500,'21/11/1973',4000,6);
insert into piloto values (4,'alberto',3000,'14/10/1980',5200,9);
insert into piloto values (5,'ricardo',1500,'19/12/1960',5000,5);
insert into piloto values (6,'ernesto',1800,'11/07/1968',5500,8);
insert into piloto values (7,'hector',2200,'21/10/1965',6000,17);
insert into piloto values (8,'maira',3200,'06/05/1956',5800,5);
insert into piloto values (9,'elberto',2100,'25/10/1957',5500,9);
insert into piloto values (10,'richard',4000,'27/11/1966',6000,5);
insert into piloto values (11,'luis',3000,'28/12/1955',4800,12);
insert into piloto values (12,'jesus',1600,'16/11/1962',3900,13);
insert into piloto values (13,'albert',2000,'30/11/1969',6000,15);
insert into piloto values (14,'roso',1400,'01/03/1970',4700,9);
insert into piloto values (15,'Javier',1200,'12/08/1974',4400,8);
insert into piloto values (16,'rosa',1500,'13/09/1970',3300,4);
insert into piloto values (17,'richard',2700,'24/10/1965',6000,12);
insert into piloto values (18,'maira',3240,'04/01/1966',5000,25);
insert into piloto values (19,'elbert',2400,'24/11/1967',5600,19);
insert into piloto values (20,'richard',3000,'28/11/1968',6600,15);
insert into piloto values (21,'erick',3300,'28/02/1965',4880,22);
insert into piloto values (22,'jesus',1300,'15/11/1967',3900,23);
insert into piloto values (23,'albert',2500,'20/11/1967',6000,5);
insert into piloto values (24,'remigio',1500,'04/05/1977',4700,9);
insert into piloto values (25,'eduard',1200,'15/08/1974',4400,8);
insert into piloto values (26,'dario',1700,'15/07/1968',5000,11);

insert into auxiliar_vuelo values (1,'rosa','f','21/09/1979',1500,7);
insert into auxiliar_vuelo values (2,'abel','m','13/07/1985',2000,11);
insert into auxiliar_vuelo values (3,'rosalba','f','16/11/1983',1400,3);
insert into auxiliar_vuelo values (4,'ivan','m','18/10/1990',1400,3);
insert into auxiliar_vuelo values (5,'alba','f','22/05/1986',1500,4);
insert into auxiliar_vuelo values (6,'maria','f','23/08/1987',1800,5);
insert into auxiliar_vuelo values (7,'edna','f','13/08/1984',2200,7);
insert into auxiliar_vuelo values (8,'jairo','m','26/03/1976',2300,8);
insert into auxiliar_vuelo values (9,'richard','m','09/11/1977',2100,8);
insert into auxiliar_vuelo values (10,'edith','f','05/10/1975',1400,13);
insert into auxiliar_vuelo values (11,'stefany','f','30/09/1980',1900,13);
insert into auxiliar_vuelo values (12,'mirta','f','11/05/1984',2200,12);
insert into auxiliar_vuelo values (13,'isabel','f','19/12/1985',2500,8);
insert into auxiliar_vuelo values (14,'marcela','f','05/10/1985',2600,9);
insert into auxiliar_vuelo values (15,'liseth','f','23/06/1986',2400,9);
insert into auxiliar_vuelo values (16,'lisette','f','26/09/1982',2700,6);
insert into auxiliar_vuelo values (17,'mariana','f','17/08/1984',1900,6);

insert into muelle values (1,'nacional',10,5);
insert into muelle values (2,'nacional',6,1);
insert into muelle values (3,'internacional',10,2);
insert into muelle values (4,'nacional',10,9);
insert into muelle values (5,'nacional',10,4);
insert into muelle values (6,'internacional',6,3);
insert into muelle values (7,'local',10,3);
insert into muelle values (8,'local',10,11);
insert into muelle values (9,'nacional',10,11);
insert into muelle values (10,'internacional',12,1);
insert into muelle values (11,'local',10,10);
insert into muelle values (12,'nacional',10,3);
insert into muelle values (13,'nacional',10,2);
insert into muelle values (14,'internacional',12,7);
insert into muelle values (15,'nacional',10,10);
insert into muelle values (16,'nacional',10,8);

insert into empleado values (1, 'juan', '10/10/1980',3200,13,2);
insert into empleado values (2, 'esteban', '18/11/1977',1100,16,1);
insert into empleado values (3, 'kevin', '15/09/1966',1100,6,3);
insert into empleado values (4, 'diana', '09/03/1988',1400,8,5);
insert into empleado values (5, 'ariana', '30/05/1979',2300,10,5);
insert into empleado values (6, 'juan', '28/06/1959',1500,6,5);
insert into empleado values (7, 'adriana', '28/02/1978',1900,5,6);
insert into empleado values (8, 'adolfo', '10/12/1969',1250,17,4);
insert into empleado values (9, 'miguel', '12/10/1954',4900,9,6);
insert into empleado values (10, 'rosa', '06/10/1979',3990,8,5);
insert into empleado values (11, 'pablo', '09/09/1987',1000,15,2);
insert into empleado values (12, 'paola', '09/08/1976',2700,4,6);
insert into empleado values (13, 'liseth', '22/12/1981',1500,7,3);
insert into empleado values (14, 'maria', '13/10/1972',1800,8,3);
insert into empleado values (15, 'juan', '23/03/1983',1200,10,2);
insert into empleado values (16, 'martha', '17/08/1966',1400,12,1);
insert into empleado values (17, 'adrian', '28/07/1977',1900,5,6);
insert into empleado values (18, 'adolf', '15/12/1979',1250,17,2);
insert into empleado values (19, 'michel', '22/10/1984',900,9,6);
insert into empleado values (20, 'dora', '26/10/1989',990,8,3);
insert into empleado values (21, 'paola', '29/09/1988',3000,5,2);
insert into empleado values (22, 'paola', '09/08/1979',1700,14,6);
insert into empleado values (23, 'emma', '22/12/1981',1500,7,3);
insert into empleado values (24, 'martha', '18/11/1979',1800,8,3);
insert into empleado values (25, 'jhon', '23/03/1983',3200,10,1);
insert into empleado values (26, 'martin', '17/08/1966',1400,12,1);
insert into empleado values (27, 'juanita', '28/08/1979',2500,1,1);

insert into cubre values (1, '17/11/2008', 12,9);
insert into cubre values (2, '05/11/2009', 3,5);
insert into cubre values (3, '23/02/2008', 15,16);
insert into cubre values (4, '22/01/2007', 4,8);
insert into cubre values (5, '09/09/2006', 6,20);
insert into cubre values (6, '17/10/2006', 4,5);
insert into cubre values (7, '14/12/2008', 5,6);
insert into cubre values (8, '16/08/2007', 26,20);
insert into cubre values (9, '28/04/2009', 9,6);
insert into cubre values (10, '30/09/2009',5,17);
insert into cubre values (11, '25/08/2008',4,15);
insert into cubre values (12, '11/06/2007',9,3);
insert into cubre values (13, '04/06/2009',5,6);
insert into cubre values (14, '08/05/2007',8,8);
insert into cubre values (15, '31/03/2008',15,2);
insert into cubre values (16, '17/10/2009',24,15);
insert into cubre values (17, '14/12/2010',15,16);
insert into cubre values (18, '16/08/2010',26,8);
insert into cubre values (19, '28/04/2009',9,6);
insert into cubre values (20, '30/09/2009',15,7);
insert into cubre values (21, '25/08/2008', 14,15);
insert into cubre values (22, '11/06/2009', 29,3);
insert into cubre values (23, '04/06/2009', 5,16);
insert into cubre values (24, '08/05/2010', 8,8);
insert into cubre values (25, '31/03/2008', 5,12);

insert into transporta values ('22/03/2008',12, 33);
insert into transporta values ('13/01/2009',13, 22);
insert into transporta values ('01/03/2009',15, 8);
insert into transporta values ('15/11/2007',11, 9);
insert into transporta values ('29/09/2008',6, 39);
insert into transporta values ('30/07/2008',7, 5);
insert into transporta values ('31/10/2007',6, 37);
insert into transporta values ('25/02/2009',8, 18);
insert into transporta values ('04/04/2008',15, 5);
insert into transporta values ('03/03/2007',9, 36);
insert into transporta values ('21/08/2008',16, 9);
insert into transporta values ('24/06/2009',9, 8);
insert into transporta values ('08/07/2008',11, 47);
insert into transporta values ('01/05/2006',14, 41);
insert into transporta values ('01/03/2009',25, 13);
insert into transporta values ('15/11/2007',4, 9);
insert into transporta values ('29/09/2008',16, 49);
insert into transporta values ('30/07/2008',17, 55);
insert into transporta values ('31/10/2007',16, 7);
insert into transporta values ('25/02/2009',8, 8);
insert into transporta values ('04/04/2008',15, 15);
insert into transporta values ('03/03/2007',9, 16);
insert into transporta values ('21/08/2008',16, 24);
insert into transporta values ('24/06/2009',6, 58);
insert into transporta values ('25/02/2009',28, 48);
insert into transporta values ('04/04/2008',15, 52);
insert into transporta values ('03/03/2007',29, 36);
insert into transporta values ('24/06/2009',29, 8);
insert into transporta values ('08/07/2008',30, 47);
insert into transporta values ('01/05/2006',24, 11);
insert into transporta values ('01/03/2009',25, 43);
insert into transporta values ('15/11/2007',4, 49);
insert into transporta values ('29/09/2008',26, 39);
insert into transporta values ('30/07/2008',17, 25);

insert into aterriza values ('24/04/2009',13, 19);
insert into aterriza values ('23/05/2008',12, 18);
insert into aterriza values ('23/01/2009',17, 18);
insert into aterriza values ('22/07/2009',14, 15);
insert into aterriza values ('11/09/2007',2, 17);
insert into aterriza values ('29/09/2008',16, 20);
insert into aterriza values ('13/07/2009',4, 12);
insert into aterriza values ('14/11/2007',13, 19);
insert into aterriza values ('25/02/2008',20, 8);
insert into aterriza values ('04/05/2007',4, 6);
insert into aterriza values ('03/03/2008',7, 16);
insert into aterriza values ('21/08/2008',4, 14);
insert into aterriza values ('24/06/2009',6, 8);
insert into aterriza values ('08/08/2008',11, 12);
insert into aterriza values ('01/07/2007',8, 15);
insert into aterriza values ('23/01/2009',7, 8);
insert into aterriza values ('22/07/2009',14, 5);
insert into aterriza values ('11/09/2007',18, 17);
insert into aterriza values ('29/09/2008',6, 15);
insert into aterriza values ('13/07/2009',14, 5);
insert into aterriza values ('14/11/2007',11, 19);
insert into aterriza values ('25/02/2008',2, 18);
insert into aterriza values ('04/05/2007',4, 16);
insert into aterriza values ('03/03/2008',17, 6);
insert into aterriza values ('21/08/2008',4, 4);


insert into realiza values (8, 6, '05/09/2007');
insert into realiza values (25, 4, '11/03/2009');
insert into realiza values (19, 13, '12/04/2007');
insert into realiza values (15, 8, '24/05/2008');
insert into realiza values (7, 1, '22/07/2007');
insert into realiza values (16, 2, '14/10/2008');
insert into realiza values (5, 4, '18/12/2010');
insert into realiza values (18, 9, '28/09/2009');
insert into realiza values (7, 9, '18/12/2007');
insert into realiza values (19, 8, '19/09/2009');
insert into realiza values (10, 16, '09/07/2007');
insert into realiza values (11, 3, '27/08/2010');
insert into realiza values (6, 15, '01/05/2008');
insert into realiza values (8, 3, '08/08/2009');
insert into realiza values (12, 14, '11/07/2010');
insert into realiza values (19, 3, '12/04/2007');
insert into realiza values (5, 18, '24/06/2008');
insert into realiza values (17, 1, '22/05/2007');
insert into realiza values (6, 12, '14/10/2008');
insert into realiza values (25, 14, '18/11/2010');
insert into realiza values (8, 9, '28/02/2010');
insert into realiza values (17, 9, '18/12/2007');
insert into realiza values (9, 18, '19/03/2009');
insert into realiza values (20, 16, '09/07/2010');
insert into realiza values (21, 19, '27/08/2010');
